@@ -1,4 +1,4 @@
-globalsInstancefrom flask import send_from_directory
+from flask import send_from_directory
 from flask_swagger_ui import get_swaggerui_blueprint
 from python_helper import Constant as c
 from python_helper import log, StringHelper, ReflectionHelper, ObjectHelper
